@@ -89,8 +89,6 @@ def main():
                 target = " ".join(input.split(" ")[int(target[0]): int(target[1])])
             if 'onebyone' in type and arg.beamsearch:
                 predicted = result_dict['label_map'][eval_pos][0]
-            elif 'classify' in type:
-                predicted = result[0]
             elif 'tag' in type:
                 predicted = [list(d.values())[0] for d in result_dict['label_map']]
             else:
